#ifndef CHEXT_H
#define CHEXT_H

/**
 * Searches for the last occurrence of @a what within @a where.
 * If there are several occurrences of @a what this function will
 * return the position of the last one.
 * @param where The text where to search
 * @param what The character to be searched
 * @return The index where @a what starts, or -1 if not found.
*/
long find_last_pos(const char* where, char what);

/**
 * Searches for the last occurrence of @a what within @a where.
 * If there are several occurrences of @a what this function will
 * return a pointer where the last one starts.
 * @param where The text where to search
 * @param what The character to be searched
 * @return A pointer where @a what starts, or NULL if not found.
*/
const char* find_last(const char* where, char what);

/**
 * Return the length of the given text
 * @param text The text to be analyzed
 * @return The count of characters in @a text
*/
long string_length(const char* text);

/**
 * Copies @a length characters from @a source to @a target
 * @param length Number of characters to be copied
 * @param source Pointer to the string to be copied from
 * @param target Pointer to the string to be copied to
*/
void string_copy(long length, const char* source, char* target);

/**
 * Copies @a length characters from @a source to @a target
 * @param length Number of characters to be copied
 * @param source Pointer to the string to be copied from
 * @param target Pointer to the string to be copied to
*/
void string_copy_ptr(long length, const char* source, char* target);

#endif // CHEXT_H
